@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2013 Emweb bvba, Leuven, Belgium.
+ * Copyright (C) 2013 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -207,7 +207,7 @@ public:
    (WGLWidget::Program program, const std::string &attrib)
     override;
   virtual WGLWidget::UniformLocation getUniformLocation
-    (WGLWidget::Program program, const std::string location)
+    (WGLWidget::Program program, const std::string &location)
     override;
   virtual void hint(WGLWidget::GLenum target, WGLWidget::GLenum mode)
     override;
@@ -427,7 +427,7 @@ private:
 
   WGLWidget::Buffer currentlyBoundBuffer_;
   WGLWidget::Texture currentlyBoundTexture_;
-  std::vector<std::unique_ptr<WResource>> binaryResources_;
+  std::vector<std::unique_ptr<WResource> > binaryResources_;
   struct PreloadImage {
     PreloadImage(const std::string& r, const std::string& u, unsigned i) :
       jsRef(r), url(u), id(i) {}
